#
# Conditional build:
%bcond_with	tests	# do not perform "make test" (they use network)
%bcond_without	python2 # CPython 2.x module
%bcond_without	python3 # CPython 3.x module

%define 	module	libcloud
Summary:	Unified Python API for cloud service providers
Name:		python-%{module}
Version:	0.14.1
Release:	3
License:	Apache v2.0
Group:		Libraries/Python
Source0:	ftp://apache.cs.utah.edu/apache.org/libcloud/apache-%{module}-%{version}.tar.bz2
# Source0-md5:	0270c54b3f61a60a008271d92addb7b8
Patch0:		cacerts_path.patch
URL:		https://libcloud.apache.org/
BuildRequires:	rpm-pythonprov
BuildRequires:	rpmbuild(macros) >= 1.710
BuildRequires:	sed >= 4.0
%if %{with python2}
BuildRequires:	python-devel
BuildRequires:	python-distribute
%{?with_tests:BuildRequires:	python-mock}
%endif
%if %{with python3}
BuildRequires:	python3-devel
%{?with_tests:BuildRequires:	python3-mock}
BuildRequires:	python3-modules
%endif
Requires:	python-modules
BuildArch:	noarch
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
Libcloud is a Python library for interacting with many of the popular
cloud service providers using a unified API. It was created to make it
easy for developers to build products that work between any of the
services that it supports.

Resource you can manage with Libcloud are divided in the following
categories:

- Cloud Servers and Block Storage - services such as Amazon EC2 and
  Rackspace CloudServers
- Cloud Object Storage and CDN - services such as Amazon S3 and
  Rackspace CloudFiles
- Load Balancers as a Service - services such as Amazon Elastic Load
  Balancer and GoGrid LoadBalancers
- DNS as a Service - services such as Amazon Route 53 and Zerigo

%package -n python3-%{module}
Summary:	Unified Python API for cloud service providers
Group:		Libraries/Python

%description -n python3-%{module}
Libcloud is a Python library for interacting with many of the popular
cloud service providers using a unified API. It was created to make it
easy for developers to build products that work between any of the
services that it supports.

Resource you can manage with Libcloud are divided in the following
categories:

- Cloud Servers and Block Storage - services such as Amazon EC2 and
  Rackspace CloudServers
- Cloud Object Storage and CDN - services such as Amazon S3 and
  Rackspace CloudFiles
- Load Balancers as a Service - services such as Amazon Elastic Load
  Balancer and GoGrid LoadBalancers
- DNS as a Service - services such as Amazon Route 53 and Zerigo

%prep
%setup -q -n apache-%{module}-%{version}

%patch0 -p1

cp libcloud/test/secrets.py-dist libcloud/test/secrets.py

%{__sed} -i -e '1s,^#!.*python,#!%{__python},' demos/*.py example_*.py

%build
%if %{with python2}
%py_build %{?with_tests:test}
%endif

%if %{with python3}
%py3_build %{?with_tests:test}
%endif

%install
rm -rf $RPM_BUILD_ROOT

%if %{with python2}
%py_install

%py_postclean
%endif

%if %{with python3}
%py3_install
%endif

%if %{with python2}
install -d $RPM_BUILD_ROOT%{_examplesdir}/%{name}-%{version}
cp -a example_*.py demos $RPM_BUILD_ROOT%{_examplesdir}/%{name}-%{version}
%endif
%if %{with python3}
install -d $RPM_BUILD_ROOT%{_examplesdir}/python3-%{module}-%{version}
cp -a example_*.py demos $RPM_BUILD_ROOT%{_examplesdir}/python3-%{module}-%{version}
find $RPM_BUILD_ROOT%{_examplesdir}/python3-%{module}-%{version} -name '*.py' \
	| xargs sed -i '1s|^#!.*python\b|#!%{__python3}|'
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%if %{with python2}
%files
%defattr(644,root,root,755)
%doc CHANGES.rst NOTICE README.rst
%{py_sitescriptdir}/%{module}
%if "%{py_ver}" > "2.4"
%{py_sitescriptdir}/*.egg-info
%endif
%{_examplesdir}/%{name}-%{version}
%endif

%if %{with python3}
%files -n python3-%{module}
%defattr(644,root,root,755)
%doc CHANGES.rst NOTICE README.rst
%{py3_sitescriptdir}/%{module}
%{py3_sitescriptdir}/*.egg-info
%{_examplesdir}/python3-%{module}-%{version}
%endif
%changelog
* Wed Mar 30 2022 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/python-libcloud.git;a=log;h=master

* Wed Mar 30 2022 Jan Rękorajski <baggins@pld-linux.org> 5a507d0
- rebuild with tests and docs

* Mon Mar 28 2022 Jan Rękorajski <baggins@pld-linux.org> 351075c
- Release 2 (by relup.sh)

* Mon Mar 28 2022 Jan Rękorajski <baggins@pld-linux.org> ccb00e9
- drop python3-distribute deps

* Sun Nov 29 2015 Jacek Konieczny <jajcus@jajcus.net> 19247e7
- BR: rpmbuild(macros) >= 1.710

* Sat Nov 28 2015 Jacek Konieczny <jajcus@jajcus.net> 3aa3cea
- automatic change: use py_build/py_install macros

* Tue Feb 18 2014 Jacek Konieczny <j.konieczny@eggsoft.pl> 6dc6d65
- Disable tests by default

* Tue Feb 18 2014 Jacek Konieczny <j.konieczny@eggsoft.pl> bee5721
- new package

